# mongo-helpers-python

Aggregation helpers for MongoDB.

## Compatibility with Python versions

Will follow the same compatibility timeline for the PyMongo driver:
https://www.mongodb.com/docs/languages/python/pymongo-driver/current/compatibility/#compatibility-table-legend
